package VMOMI::DistributedVirtualSwitchNicTeamingPolicyMode;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
